# CITIfile

Read CITI format file by python.

## Introduction

CITIfile is a tiny library that allows you use python to read CITIfile.

## Websites

Main website: https://github.com/TitorX/CITIfile

CITIfile Definitions: http://literature.cdn.keysight.com/litweb/pdf/ads15/cktsim/ck2016.html

## Installation
```shell script
pip install CITIfile
```

## Reports

Report bugs or ask questions at https://github.com/TitorX/CITIfile/issues.

## Contact

Written by Shoukun Sun.

Email: titor.sun@gmail.com
